# FACT Data API Reader
`FACT_data_API_reader` is a Julia module designed to query and retrieve results from [`FACT Data services`](https://git.nilu.no/fact/data). This utility module allows for efficient access to various components of FACT Data, providing an interface to query them and obtain results in the form of Julia DataFrames.

---

[![GitLab License](https://img.shields.io/gitlab/license/fact%2Futils%2FFACT_data_API_reader.jl?gitlab_url=https%3A%2F%2Fgit.nilu.no&style=flat&color=orange)](https://www.gnu.org/licenses/agpl-3.0.en.html#license-text)
[![DOI](https://img.shields.io/badge/DOI-10.17605%2FOSF.IO%2FHSJY5-blue?style=flat)](https://doi.org/10.17605/OSF.IO/HSJY5)

---

## Use
1. To install the package in your project:
```julia
using Pkg
Pkg.add("https://git.nilu.no/fact/utils/FACT_data_API_reader.jl.git")
```
2. To use the package:
```julia
using FACT_data_API_reader
``````
3. Query FACT Data services (they must be running!):

You can query different components of FACT_data. For example:
```julia
geo_objects = get_geo_objects(...)
travel_data_eu = get_travel_data_eu(...)
annual_jobs = get_annual_jobs(...)
```
Replace ... with the necessary parameters for each function.

---
## Specifications
Please refer to the package documentation for details on how to access Docker API: https://fact.pages.nilu.no/utils/FACT_data_API_reader.jl

`FACT_data_API_reader` includes the following functionalities to access the different [`FACT Data services`](https://git.nilu.no/fact/data):
1. Geographical Data: Retrieve geographical objects.
2. Travel Data (EU and NA): Obtain travel-related data for Europe and North America.
3. Annual Jobs Data: Access data related to jobs on an annual basis.
4. Population Data: Query annual population statistics.
5. Air Traffic Data: Get information on airports and their traffic.
6. Elevation Data: Access elevation-related data through a web service.
7. Rail Stations and Lines: Retrieve data about rail stations and lines.
8. Ports Tonnage: Get information on ports and their tonnage.
9. Power Stations and Lines: Access data on power stations and power lines.
10. Land Use Data: Obtain land use data.
11. Geology and Minerals: Query geological data and mineral resources.
12. Building footprint and height: Obtain estimation on buildings footprints from ML on multiple remote sensing sources.

---
## Notes
- The module is structured to interact with both databases and web services, depending on the type of data being accessed.
- Some functionalities are commented out in the current version and might be included in future releases.
- This module is designed for use with Julia and requires an understanding of Julia DataFrames for effective utilization.
- Tests are available under the test directory, providing real-world use cases in both the US and EU.

For more detailed information on each function and its parameters, please refer to the individual function documentation within the module.

---
## Author
Riccardo Boero - ribo@nilu.no

## License
[![AGPL v3](https://www.gnu.org/graphics/agplv3-88x31.png "License Icon")](https://www.gnu.org/licenses/agpl-3.0.en.html#license-text)

## Citation

- Boero, Riccardo. 2024. “FACT Utils: FACT Data API Reader.” OSF. [doi:10.17605/OSF.IO/HSJY5](https://doi.org/10.17605/OSF.IO/HSJY5). 

Part of the Fine scAle eConomic daTa - FACT project:
- Boero, Riccardo. 2024. “Fine scAle eConomic daTa - FACT.” OSF. [doi:10.17605/OSF.IO/PV4ZW](https://doi.org/10.17605/OSF.IO/PV4ZW). 
